using projet.dal;
using projet.modele;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Mediatek86.Controller
{
    internal class ModifierAbsenceController
    {
        private readonly ServiceAccess serviceAccess;
        private readonly AbsenceAccess absenceAccess;
        private readonly MotifAccess motifAccess;
        public ModifierAbsenceController()
        {
            serviceAccess = new ServiceAccess();
            absenceAccess = new AbsenceAccess();
            motifAccess = new MotifAccess();
        }
        public List<Motif> GetAllMotifs()
        {
            return motifAccess.GetAllMotifs();
        }
        public void ModifierAbsence(Absence absence, Personnel personne)
        {
            absenceAccess.ModifierAbsence(absence, personne);
        }
        public int GetMotifIdByLibelle(string libelle)
        {
            return motifAccess.GetMotifIdByLibelle(libelle);
        }
        public Motif GetMotifById(int id)
        {
            return motifAccess.GetMotifById(id);
        }
        public string GetLibelleById(int id)
        {
            return motifAccess.GetLibelleById(id);
        }
    }
}
